<?php 
/*
Plugin Name: Force HTTPS
Version: 1.0.0
Description: Gives the capacity to force https connections on https enabled servers.
Plugin URI: 
Author: bonhommedeneige
Author URI: 
*/

defined('PHPWG_ROOT_PATH') or die('Hacking attempt!');

global $cong,$prefixeTable;

// +-----------------------------------------------------------------------+
// | Define plugin constants                                               |
// +-----------------------------------------------------------------------+
defined('FORCE_HTTPS_ID') or define('FORCE_HTTPS_ID', basename(dirname(__FILE__)));
define('FORCE_HTTPS_PATH' ,   PHPWG_PLUGINS_PATH . FORCE_HTTPS_ID . '/');
define('FORCE_HTTPS_VERSION', '1.0.0');
// this is automatically updated by PEM if you publish your plugin with SVN, otherwise you musn't forget to change it, as well as "Version" in the plugin header


// +-----------------------------------------------------------------------+
// | Add event handlers                                                    |
// +-----------------------------------------------------------------------+
// init the plugin
add_event_handler('init', 'piwigo_force_https_init');

if (defined('IN_ADMIN'))
{
  // admin plugins menu link
  add_event_handler('get_admin_plugin_menu_links', 'piwigo_force_https_admin_plugin_menu_links');
}

add_event_handler('loc_end_page_header', 'piwigo_force_https_header' );

/**
 * Admin plugins menu link
 */
function piwigo_force_https_admin_plugin_menu_links($menu) 
{
  array_push($menu, array(
    'NAME' => l10n('Force HTTPS'),
    'URL' => get_admin_plugin_menu_link(dirname(__FILE__).'/admin.php'),
  ));
  return $menu;
}

/**
 * Http connections control
 */
function piwigo_force_https_header() {
	global $conf;

	// Force https connection
	$use_sts = isset($conf['fhp_active']) ? strbool($conf['fhp_active']) : 'false';

	if ($use_sts == 'true') {
		if (isset($_SERVER['HTTPS'])) {
		  header('Strict-Transport-Security: max-age=500');
		} elseif ($use_sts && !isset($_SERVER['HTTPS'])) {
		  header('Location: https://'.$_SERVER["HTTP_HOST"].$_SERVER['REQUEST_URI']);
		}
	}
}

/**
 * plugin initialization
 *   - check for upgrades
 *   - unserialize configuration
 *   - load language
 */
function piwigo_force_https_init()
{
  global $conf, $pwg_loaded_plugins;
  
  // apply upgrade if needed
  if (
    FORCE_HTTPS_VERSION == 'auto' or
    $pwg_loaded_plugins[FORCE_HTTPS_ID]['version'] == 'auto' or
    version_compare($pwg_loaded_plugins[FORCE_HTTPS_ID]['version'], FORCE_HTTPS_VERSION, '<')
  )
  {
    // call install function
    include_once(FORCE_HTTPS_PATH . 'include/install.inc.php');
    piwigo_force_https_install();
    
    // update plugin version in database
    if ( $pwg_loaded_plugins[FORCE_HTTPS_ID]['version'] != 'auto' and FORCE_HTTPS_VERSION != 'auto' )
    {
      $query = '
		UPDATE '. PLUGINS_TABLE .'
		SET version = "'. FORCE_HTTPS_VERSION .'"
		WHERE id = "'. FORCE_HTTPS_ID .'"';
      pwg_query($query);
      
      $pwg_loaded_plugins[FORCE_HTTPS_ID]['version'] = FORCE_HTTPS_VERSION;
      
      if (defined('IN_ADMIN'))
      {
        $_SESSION['page_infos'][] = 'Force https updated to version '. FORCE_HTTPS_VERSION;
      }
    }
  }
  
  // load plugin language file
  load_language('plugin.lang', FORCE_HTTPS_PATH);
  
  // prepare plugin configuration
  $conf['piwigo_force_https'] = unserialize($conf['piwigo_force_https']);
}

function strbool($value)
{
	return $value ? 'true' : 'false';
}
?>